Command

Enum Command 

pub enum Command {
    SendHeader {
        header: Box<DStarHeader>,
        stream_id: StreamId,
        reply: Sender<Result<(), ShellError>>,
    },
    SendVoice {
        stream_id: StreamId,
        seq: u8,
        frame: Box<VoiceFrame>,
        reply: Sender<Result<(), ShellError>>,
    },
    SendEot {
        stream_id: StreamId,
        seq: u8,
        reply: Sender<Result<(), ShellError>>,
    },
    Disconnect {
        reply: Sender<()>,
    },
}
Commands sent from a user-facing super::AsyncSession handle to the spawned tokio task that drives the sans-io core.

Variants



SendHeader

Send a voice header and start a new outbound stream.

Fields

header: Box<DStarHeader>

The header to transmit.

stream_id: StreamId

Stream id for the voice burst.

reply: Sender<Result<(), ShellError>>

Reply channel — Ok(()) on success, or the shell error.



SendVoice

Send a voice data frame.

Fields

stream_id: StreamId

Stream id.

seq: u8

Frame seq (0..21 cycle).

frame: Box<VoiceFrame>

9 AMBE bytes + 3 slow data bytes.

reply: Sender<Result<(), ShellError>>

Reply channel.



SendEot

Send a voice EOT and close the outbound stream.

Fields

stream_id: StreamId

Stream id.

seq: u8

Final seq.

reply: Sender<Result<(), ShellError>>

Reply channel.



Disconnect

Initiate a graceful disconnect and wait for UNLINK ACK or timeout.

Fields

reply: Sender<()>

Reply channel — fires when disconnect is complete.